@@ -17,8 +17,8 @@ FXDEFMAP(ArchInputDialog) ArchInputDialogMap[]=
 {
 	FXMAPFUNC(SEL_KEYPRESS,0,ArchInputDialog::onCmdKeyPress),
 	FXMAPFUNC(SEL_COMMAND,ArchInputDialog::ID_BROWSE_PATH,ArchInputDialog::onCmdBrowsePath),
-	FXMAPFUNCS(SEL_COMMAND,ArchInputDialog::ID_FORMAT_TAR_GZ,ArchInputDialog::ID_FORMAT_ARJ,ArchInputDialog::onCmdOption),
-	FXMAPFUNCS(SEL_UPDATE,ArchInputDialog::ID_FORMAT_TAR_GZ,ArchInputDialog::ID_FORMAT_ARJ,ArchInputDialog::onUpdOption),
+	FXMAPFUNCS(SEL_COMMAND,ArchInputDialog::ID_FORMAT_TAR_GZ,ArchInputDialog::ID_FORMAT_Z,ArchInputDialog::onCmdOption),
+	FXMAPFUNCS(SEL_UPDATE,ArchInputDialog::ID_FORMAT_TAR_GZ,ArchInputDialog::ID_FORMAT_Z,ArchInputDialog::onUpdOption),
 };
 
 
@@ -65,14 +65,13 @@ ArchInputDialog::ArchInputDialog(FXWindow *win,FXString inp):
 	option_zip = new FXOption(popup,_("zip\tArchive format is zip"),NULL,this,ID_FORMAT_ZIP,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
 	option_7zip = new FXOption(popup,_("7z\tArchive format is 7z"),NULL,this,ID_FORMAT_7ZIP,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
 	option_tbz2 = new FXOption(popup,_("tar.bz2\tArchive format is tar.bz2"),NULL,this,ID_FORMAT_TAR_BZ2,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
+	option_txz = new FXOption(popup,_("tar.xz\tArchive format is tar.xz"),NULL,this,ID_FORMAT_TAR_XZ,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
 	option_tar = new FXOption(popup,_("tar\tArchive format is tar"),NULL,this,ID_FORMAT_TAR,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
 	option_taz = new FXOption(popup,_("tar.Z\tArchive format is tar.Z"),NULL,this,ID_FORMAT_TAR_Z,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
 	option_gz = new FXOption(popup,_("gz\tArchive format is gz"),NULL,this,ID_FORMAT_GZ,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
 	option_bz2 = new FXOption(popup,_("bz2\tArchive format is bz2"),NULL,this,ID_FORMAT_BZ2,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
+	option_xz = new FXOption(popup,_("xz\tArchive format is xz"),NULL,this,ID_FORMAT_XZ,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
 	option_z = new FXOption(popup,_("Z\tArchive format is Z"),NULL,this,ID_FORMAT_Z,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
-	option_rar = new FXOption(popup,_("rar\tArchive format is rar"),NULL,this,ID_FORMAT_RAR,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
-	option_lzh = new FXOption(popup,_("lzh\tArchive format is lzh"),NULL,this,ID_FORMAT_LZH,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
-	option_arj = new FXOption(popup,_("arj\tArchive format is arj"),NULL,this,ID_FORMAT_ARJ,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
 	optionmenu = new FXOptionMenu(matrix4,popup,LAYOUT_TOP|FRAME_RAISED|FRAME_THICK|JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
 }
 
@@ -156,6 +155,12 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar.gz";
 			input->setText(str);
 		}
+		else if (ext2=="tar.xz")
+		{
+			str=str.left(str.length()-7);
+			str=str+".tar.gz";
+			input->setText(str);
+		}
 		else if (ext2=="tar.z")
 		{
 			str=str.left(str.length()-6);
@@ -168,13 +173,13 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar.gz";
 			input->setText(str);
 		}
-		else if (ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
+		else if (ext1=="txz" || ext1=="taz" || ext1=="bz2" || ext1=="tar" || ext1=="zip")
 		{
 			str=str.left(str.length()-4);
 			str=str+".tar.gz";
 			input->setText(str);
 		}
-		else if (ext1=="gz")
+		else if (ext1=="xz" || ext1=="7z" || ext1=="gz")
 		{
 			str=str.left(str.length()-3);
 			str=str+".tar.gz";
@@ -202,7 +207,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 		{
 			input->setText(str);
 		}
-		else if (ext2=="tar.gz")
+		else if (ext2=="tar.gz" || ext2=="tar.xz")
 		{
 			str=str.left(str.length()-7);
 			str=str+".tar.bz2";
@@ -214,13 +219,13 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar.bz2";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
+		else if (ext1=="tgz" || ext1=="txz" || ext1=="taz" || ext1=="bz2" || ext1=="tar" || ext1=="zip")
 		{
 			str=str.left(str.length()-4);
 			str=str+".tar.bz2";
 			input->setText(str);
 		}
-		else if (ext1=="gz")
+		else if (ext1=="gz" || ext1=="7z" || ext1=="xz")
 		{
 			str=str.left(str.length()-3);
 			str=str+".tar.bz2";
@@ -239,10 +244,61 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 		}
 	}
 
+	else if (FXSELID(sel)==ID_FORMAT_TAR_XZ)
+	{
+
+		// Handle different archive formats
+		if (ext2=="tar.xz" || ext1=="txz")
+		{
+			input->setText(str);
+		}
+		else if (ext2=="tar.bz2")
+		{
+			str=str.left(str.length()-8);
+			str=str+".tar.xz";
+			input->setText(str);
+		}
+		else if (ext2=="tar.gz")
+		{
+			str=str.left(str.length()-7);
+			str=str+".tar.xz";
+			input->setText(str);
+		}
+		else if (ext2=="tar.z")
+		{
+			str=str.left(str.length()-6);
+			str=str+".tar.xz";
+			input->setText(str);
+		}
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="taz" || ext1=="tar" || ext1=="zip")
+		{
+			str=str.left(str.length()-4);
+			str=str+".tar.xz";
+			input->setText(str);
+		}
+		else if (ext1=="gz" || ext1=="7z" || ext1=="xz")
+		{
+			str=str.left(str.length()-3);
+			str=str+".tar.xz";
+			input->setText(str);
+		}
+		else if (ext1=="z")
+		{
+			str=str.left(str.length()-2);
+			str=str+".tar.xz";
+			input->setText(str);
+		}
+		else
+		{			
+			str=str+".tar.xz";
+			input->setText(str);
+		}
+	}
+
 	else if (FXSELID(sel)==ID_FORMAT_TAR)
 	{
 		// Handle different archive formats
-		if (ext1=="tar" && ext2!="tar.gz" && ext2!="tar.bz2" && ext2!="tar.z")
+		if (ext1=="tar" && ext2!="tar.gz" && ext2!="tar.bz2" && ext2!="tar.z" && ext2!="tar.xz")
 		{
 			input->setText(str);
 		}
@@ -252,7 +308,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar";
 			input->setText(str);
 		}
-		else if (ext2=="tar.gz")
+		else if (ext2=="tar.gz" || ext2=="tar.xz")
 		{
 			str=str.left(str.length()-7);
 			str=str+".tar";
@@ -270,13 +326,13 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
+		else if (ext1=="tgz" || ext1=="txz" || ext1=="taz" || ext1=="bz2" || ext1=="zip")
 		{
 			str=str.left(str.length()-4);
 			str=str+".tar";
 			input->setText(str);
 		}
-		else if (ext1=="gz")
+		else if (ext1=="gz" || ext1=="7z" || ext1=="xz")
 		{
 			str=str.left(str.length()-3);
 			str=str+".tar";
@@ -298,7 +354,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 	else if (FXSELID(sel)==ID_FORMAT_TAR_Z)
 	{
 		// Handle different archive formats
-		if (ext2=="tar.Z")
+		if (ext2=="tar.Z" || ext1=="taz")
 		{
 			input->setText(str);
 		}
@@ -308,7 +364,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar.Z";
 			input->setText(str);
 		}
-		else if (ext2=="tar.gz")
+		else if (ext2=="tar.gz" || ext2=="tar.xz")
 		{
 			str=str.left(str.length()-7);
 			str=str+".tar.Z";
@@ -320,13 +376,13 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar.Z";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
+		else if (ext1=="tgz" || ext1=="txz" || ext1=="bz2" || ext1=="tar" || ext1=="zip")
 		{
 			str=str.left(str.length()-4);
 			str=str+".tar.Z";
 			input->setText(str);
 		}
-		else if (ext1=="gz")
+		else if (ext1=="gz" || ext1=="7z" || ext1=="xz")
 		{
 			str=str.left(str.length()-3);
 			str=str+".tar.Z";
@@ -358,7 +414,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".gz";
 			input->setText(str);
 		}
-		else if (ext2=="tar.gz")
+		else if (ext2=="tar.gz" || ext2=="tar.xz")
 		{
 			str=str.left(str.length()-7);
 			str=str+".gz";
@@ -376,12 +432,18 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".gz";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
+		else if (ext1=="tgz" || ext1=="txz" || ext1=="taz" || ext1=="bz2" || ext1=="tar" || ext1=="zip")
 		{
 			str=str.left(str.length()-4);
 			str=str+".gz";
 			input->setText(str);
 		}
+		else if (ext1=="xz" || ext1=="7z")
+		{
+			str=str.left(str.length()-3);
+			str=str+".gz";
+			input->setText(str);
+		}
 		else if (ext1=="z")
 		{
 			str=str.left(str.length()-2);
@@ -395,6 +457,62 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 		}
 	}
 
+	else if (FXSELID(sel)==ID_FORMAT_XZ)
+	{
+		// Handle different archive formats
+		if (ext1=="xz" && ext2!="tar.xz")
+		{
+			input->setText(str);
+		}
+		else if (ext2=="tar.bz2")
+		{
+			str=str.left(str.length()-8);
+			str=str+".xz";
+			input->setText(str);
+		}
+		else if (ext2=="tar.gz" || ext2=="tar.xz")
+		{
+			str=str.left(str.length()-7);
+			str=str+".xz";
+			input->setText(str);
+		}
+		else if (ext2=="tar.z")
+		{
+			str=str.left(str.length()-6);
+			str=str+".xz";
+			input->setText(str);
+		}
+		else if (ext1=="tbz2")
+		{
+			str=str.left(str.length()-5);
+			str=str+".xz";
+			input->setText(str);
+		}
+		else if (ext1=="tgz" || ext1=="txz" || ext1=="taz" || ext1=="bz2" || ext1=="tar" || ext1=="zip")
+		{
+			str=str.left(str.length()-4);
+			str=str+".xz";
+			input->setText(str);
+		}
+		else if (ext1=="7z")
+		{
+			str=str.left(str.length()-3);
+			str=str+".xz";
+			input->setText(str);
+		}
+		else if (ext1=="z")
+		{
+			str=str.left(str.length()-2);
+			str=str+".xz";
+			input->setText(str);
+		}
+		else
+		{			
+			str=str+".xz";
+			input->setText(str);
+		}
+	}
+
 	else if (FXSELID(sel)==ID_FORMAT_BZ2)
 	{
 		// Handle different archive formats
@@ -409,7 +527,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".bz2";
 			input->setText(str);
 		}
-		else if (ext2=="tar.gz")
+		else if (ext2=="tar.gz" || ext2=="tar.xz")
 		{
 			str=str.left(str.length()-7);
 			str=str+".bz2";
@@ -427,13 +545,13 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".bz2";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
+		else if (ext1=="tgz" || ext1=="txz" || ext1=="taz" || ext1=="tar" || ext1=="zip")
 		{
 			str=str.left(str.length()-4);
 			str=str+".bz2";
 			input->setText(str);
 		}
-		else if (ext1=="gz")
+		else if (ext1=="gz" || ext1=="xz" || ext1=="7z")
 		{
 			str=str.left(str.length()-3);
 			str=str+".bz2";
@@ -465,7 +583,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".Z";
 			input->setText(str);
 		}
-		else if (ext2=="tar.gz")
+		else if (ext2=="tar.gz" || ext2=="tar.xz")
 		{
 			str=str.left(str.length()-7);
 			str=str+".Z";
@@ -483,13 +601,13 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".Z";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="taz" || ext1=="txz" || ext1=="tar" || ext1=="zip")
 		{
 			str=str.left(str.length()-4);
 			str=str+".Z";
 			input->setText(str);
 		}
-		else if (ext1=="gz")
+		else if (ext1=="gz" || ext1=="7z" || ext1=="xz")
 		{
 			str=str.left(str.length()-3);
 			str=str+".Z";
@@ -515,7 +633,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".zip";
 			input->setText(str);
 		}
-		else if (ext2=="tar.gz")
+		else if (ext2=="tar.gz" || ext2=="tar.xz")
 		{
 			str=str.left(str.length()-7);
 			str=str+".zip";
@@ -533,13 +651,13 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".zip";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="7z" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="taz" || ext1=="txz" || ext1=="tar")
 		{
 			str=str.left(str.length()-4);
 			str=str+".zip";
 			input->setText(str);
 		}
-		else if (ext1=="gz")
+		else if (ext1=="gz" || ext1=="7z" || ext1=="xz")
 		{
 			str=str.left(str.length()-3);
 			str=str+".zip";
@@ -571,7 +689,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".7z";
 			input->setText(str);
 		}
-		else if (ext2=="tar.gz")
+		else if (ext2=="tar.gz" || ext2=="tar.xz")
 		{
 			str=str.left(str.length()-7);
 			str=str+".7z";
@@ -589,13 +707,13 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".7z";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="rar" || ext1=="lzh" || ext1=="arj")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="taz" || ext1=="txz" || ext1=="tar" || ext1=="zip")
 		{
 			str=str.left(str.length()-4);
 			str=str+".7z";
 			input->setText(str);
 		}
-		else if (ext1=="gz")
+		else if (ext1=="gz" || ext1=="xz")
 		{
 			str=str.left(str.length()-3);
 			str=str+".7z";
@@ -613,173 +731,6 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			input->setText(str);
 		}
 	}
-
-	else if (FXSELID(sel)==ID_FORMAT_RAR)
-	{
-		// Handle different archive formats
-		if (ext1=="rar")
-		{
-			input->setText(str);
-		}
-		else if (ext2=="tar.bz2")
-		{
-			str=str.left(str.length()-8);
-			str=str+".rar";
-			input->setText(str);
-		}
-		else if (ext2=="tar.gz")
-		{
-			str=str.left(str.length()-7);
-			str=str+".rar";
-			input->setText(str);
-		}
-		else if (ext2=="tar.z")
-		{
-			str=str.left(str.length()-6);
-			str=str+".rar";
-			input->setText(str);
-		}
-		else if (ext1=="tbz2")
-		{
-			str=str.left(str.length()-5);
-			str=str+".rar";
-			input->setText(str);
-		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="lzh" || ext1=="arj")
-		{
-			str=str.left(str.length()-4);
-			str=str+".rar";
-			input->setText(str);
-		}
-		else if (ext1=="gz")
-		{
-			str=str.left(str.length()-3);
-			str=str+".rar";
-			input->setText(str);
-		}
-		else if (ext1=="z")
-		{
-			str=str.left(str.length()-2);
-			str=str+".rar";
-			input->setText(str);
-		}
-		else
-		{			
-			str=str+".rar";
-			input->setText(str);
-		}
-	}
-
-	else if (FXSELID(sel)==ID_FORMAT_LZH)
-	{
-		// Handle different archive formats
-		if (ext1=="lzh")
-		{
-			input->setText(str);
-		}
-		else if (ext2=="tar.bz2")
-		{
-			str=str.left(str.length()-8);
-			str=str+".lzh";
-			input->setText(str);
-		}
-		else if (ext2=="tar.gz")
-		{
-			str=str.left(str.length()-7);
-			str=str+".lzh";
-			input->setText(str);
-		}
-		else if (ext2=="tar.z")
-		{
-			str=str.left(str.length()-6);
-			str=str+".lzh";
-			input->setText(str);
-		}
-		else if (ext1=="tbz2")
-		{
-			str=str.left(str.length()-5);
-			str=str+".lzh";
-			input->setText(str);
-		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="arj")
-		{
-			str=str.left(str.length()-4);
-			str=str+".lzh";
-			input->setText(str);
-		}
-		else if (ext1=="gz")
-		{
-			str=str.left(str.length()-3);
-			str=str+".lzh";
-			input->setText(str);
-		}
-		else if (ext1=="z")
-		{
-			str=str.left(str.length()-2);
-			str=str+".lzh";
-			input->setText(str);
-		}
-		else
-		{			
-			str=str+".lzh";
-			input->setText(str);
-		}
-	}
-	else if (FXSELID(sel)==ID_FORMAT_ARJ)
-	{
-		// Handle different archive formats
-		if (ext1=="arj")
-		{
-			input->setText(str);
-		}
-		else if (ext2=="tar.bz2")
-		{
-			str=str.left(str.length()-8);
-			str=str+".arj";
-			input->setText(str);
-		}
-		else if (ext2=="tar.gz")
-		{
-			str=str.left(str.length()-7);
-			str=str+".arj";
-			input->setText(str);
-		}
-		else if (ext2=="tar.z")
-		{
-			str=str.left(str.length()-6);
-			str=str+".arj";
-			input->setText(str);
-		}
-		else if (ext1=="tbz2")
-		{
-			str=str.left(str.length()-5);
-			str=str+".arj";
-			input->setText(str);
-		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
-		{
-			str=str.left(str.length()-4);
-			str=str+".arj";
-			input->setText(str);
-		}
-		else if (ext1=="gz")
-		{
-			str=str.left(str.length()-3);
-			str=str+".arj";
-			input->setText(str);
-		}
-		else if (ext1=="z")
-		{
-			str=str.left(str.length()-2);
-			str=str+".arj";
-			input->setText(str);
-		}
-		else
-		{			
-			str=str+".arj";
-			input->setText(str);
-		}
-	}
 			
 	return 1;
 }
@@ -804,6 +755,10 @@ long ArchInputDialog::onUpdOption(FXObject*,FXSelector sel,void*)
 	{
 		optionmenu->setCurrent(option_tbz2);	
 	}
+	else if (ext2=="tar.xz" || ext1=="txz")
+	{
+		optionmenu->setCurrent(option_txz);	
+	}
 	else if (ext2=="tar.z" || ext1=="taz")
 	{
 		optionmenu->setCurrent(option_taz);	
@@ -820,6 +775,10 @@ long ArchInputDialog::onUpdOption(FXObject*,FXSelector sel,void*)
 	{
 		optionmenu->setCurrent(option_bz2);	
 	}
+	else if (ext1=="xz")
+	{
+		optionmenu->setCurrent(option_xz);	
+	}
 	else if (ext1=="z")
 	{
 		optionmenu->setCurrent(option_z);	
@@ -832,18 +791,6 @@ long ArchInputDialog::onUpdOption(FXObject*,FXSelector sel,void*)
 	{
 		optionmenu->setCurrent(option_7zip);	
 	}
-	else if (ext1=="rar")
-	{
-		optionmenu->setCurrent(option_rar);	
-	}
-	else if (ext1=="lzh")
-	{
-		optionmenu->setCurrent(option_lzh);	
-	}
-	else if (ext1=="arj")
-	{
-		optionmenu->setCurrent(option_arj);	
-	}
 	else
 	{			
 		optionmenu->setCurrent(option_tgz);	
