@@ -15,7 +15,7 @@
 // Maximum bookmarks number
 // If modified, also change appropriate items in BookmarksMap
 // and in onUpdBookmark and Bookmarks.h
-#define MAX_BOOKMARKS 20
+#define MAX_BOOKMARKS 21
 
 
 
@@ -128,8 +128,13 @@ void Bookmarks::clear()
 // Clear the bookmarks list
 long Bookmarks::onCmdClear(FXObject*,FXSelector,void*)
 {
-    clear();
-    return 1;
+	if(BOX_CLICKED_CANCEL==MessageBox::question(FXApp::instance()->getActiveWindow(),BOX_OK_CANCEL,
+	   _("Confirm Clear Bookmarks"),_("Do you really want to clear all your bookmarks?")))
+		return 0;
+	else
+		clear();
+	
+	return 1;
 }
 
 
@@ -156,15 +161,30 @@ long Bookmarks::onUpdBookmark(FXObject *sender,FXSelector sel,void*)
     const FXchar *bookname=NULL;
     FXString string;
     FXchar key[20];
+    FXchar _char[11]={'a','b','c','d','e','f','g','h','i','j','k'};
     snprintf(key,sizeof(key)-1,"BOOKMARK%d",which);
     bookname=FXApp::instance()->reg().readStringEntry(group.text(),key,NULL);
     if(bookname)
     {
         FXString string;
-        if(which<MAX_BOOKMARKS)
+        
+        // Keyboard shortcut is 1, 2, 3...
+        if(which<10)
+        {
             string.format("&%d %s",which,bookname);
+		}
+        
+        // Keyboard shortcut is a, b, c...
+        else if(which<MAX_BOOKMARKS)
+        {
+            string.format("&%c %s",_char[which-10],bookname);
+		}
+        
+        // Should not be used
         else
+        {
             string.format("2&0 %s",bookname);
+		}
         sender->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_SETSTRINGVALUE),(void*)&string);
         sender->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_SHOW),NULL);
     }
