@@ -59,7 +59,7 @@ BrowseInputDialog::BrowseInputDialog(FXWindow *win,FXString inp,FXString message
 	// Icon and text label
 	// Note : we display the message in a TextLabel. This allows to copy/paste the file name to the input text field
 	FXMatrix *matrix1 = new FXMatrix(contents,2,MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
-	new FXLabel(matrix1,"",ic,LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FILL_ROW);
+	iconlabel = new FXLabel(matrix1,"",ic,LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FILL_ROW);
 	msg = new TextLabel(matrix1,30,0,0,LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FILL_ROW|FRAME_NONE);
 	msg->setText(message);
 	msg->setBackColor(getApp()->getBaseColor());
@@ -89,6 +89,7 @@ BrowseInputDialog::~BrowseInputDialog()
 {
 	delete input;
 	delete msg;
+	delete iconlabel;
 }
 
 long BrowseInputDialog::onCmdKeyPress(FXObject* sender,FXSelector sel,void* ptr)
@@ -186,6 +187,11 @@ void BrowseInputDialog::setText(const FXString& text)
 	input->setText(text);
 }
 
+// Change dialog icon
+void BrowseInputDialog::setIcon(FXIcon* icon)
+{
+	iconlabel->setIcon(icon);
+}
 
 void BrowseInputDialog::SelectAll()
 {
