@@ -20,6 +20,7 @@ class BrowseInputDialog : public DialogBox
 protected:
     FXTextField*       input;
     TextLabel*         msg;
+    FXLabel*			iconlabel;
     FXDataTarget*      string_target;
     FXHorizontalFrame* checkbutton;
 	FXuint			   browsetype;
@@ -41,6 +42,7 @@ public:
     long onCmdKeyPress(FXObject*,FXSelector,void*);
 	long onCmdBrowsePath(FXObject*,FXSelector,void*);
 	void setMessage(FXString);
+	void setIcon(FXIcon*);
 	void setDirectory(const FXString&);
     FXString getText();
 	void setText(const FXString&);
