@@ -100,7 +100,7 @@ void CommandWindow::create()
 	}
 
     DialogBox::create();
-    show(PLACEMENT_SCREEN);
+    show(PLACEMENT_OWNER);
     
 	// Execute command
 	execCmd(command.text());
