@@ -524,7 +524,7 @@ long DirList::onDNDDrop(FXObject* sender,FXSelector sel,void* ptr)
                 q++;
             FXString url(p,q-p);
             FXString source(FXURL::fileFromURL(url));
-            FXString target(targetdir+PATHSEPSTRING+FXPath::name(source));
+            FXString target(targetdir);
             FXString sourcedir=FXPath::directory(source);
  
             // File operation dialog, if needed
@@ -1069,24 +1069,8 @@ FXbool DirList::collapseTree(TreeItem* tree,FXbool notify)
         {
             // As a memory saving feature, all knowledge below this item
             // is deleted; we'll just recreate it when its reexpanded!
- 
- 
- 
-           
-           
-           // Faut-il garder ceci??????
            removeItems(tree->first,tree->last);
            recalc();
-		   // !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-
-
-
-
-
-
-
-
-
         }
         return TRUE;
     }
@@ -1300,9 +1284,8 @@ void DirList::scan(FXbool force)
 // List root directories
 void DirList::listRootItems()
 {
-    DirItem   *item=(DirItem*)firstitem;
-    FXIcon      *openicon;
-    FXIcon      *closedicon;
+    DirItem *item=(DirItem*)firstitem;
+    FXIcon *openicon, *closedicon;
     FileAssoc *fileassoc;
 
     // First time, make root node
@@ -1348,18 +1331,15 @@ void DirList::listRootItems()
 // List child items
 void DirList::listChildItems(DirItem *par)
 {
-    DirItem     *oldlist,*newlist,**po,**pp,**pn,*item,*link;
-    FXIcon        *openicon;
-    FXIcon        *closedicon;
-    FileAssoc   *fileassoc;
-    DIR           *dirp;
+    DirItem *oldlist, *newlist, **po, **pp, **pn, *item, *link;
+    FXIcon *openicon, *closedicon;
+    FileAssoc *fileassoc;
+    DIR *dirp;
     struct dirent *dp;
     struct stat    info;
-    FXString       pathname;
-    FXString       directory;
-    FXString       name;
-    FXint          islink;
+    FXString pathname, directory, name;
 	FXString type, mod, usrid, grpid, atts, del;
+    FXint islink;
 	long deldate;
 
     // Path to parent node
@@ -1643,6 +1623,7 @@ fnd:
 
 			// Data used to update the tooltip
 			item->tdata=item->label+"\t"+type+"\t"+mod+"\t"+usrid+"\t"+grpid+"\t"+atts+"\t"+del+"\t"+pathname;
+			item->setData(&item->tdata);
 
             // Create item
             if(id())
