@@ -49,6 +49,7 @@ public:
     DirItem(const FXString& text,FXIcon* oi=NULL,FXIcon* ci=NULL,void* ptr=NULL):FXTreeItem(text,oi,ci,ptr),assoc(NULL),link(NULL),list(NULL),size(0),date(0)
     {
         state=HASITEMS;
+        tdata="";
     }
     FXbool isDirectory() const
     {
@@ -92,7 +93,10 @@ public:
     }
     FXString getTooltipData() const
     {
-		return tdata;
+		if (getData() != NULL)
+			return tdata;
+		else
+			return "";
 	}
 };
 
