@@ -768,7 +768,7 @@ long DirPanel::onCmdProperties(FXObject* sender, FXSelector, void*)
 	FXString pathname=list->getItemPathname((TreeItem*)item);
 	
 	PropertiesBox* attrdlg=new PropertiesBox(this,FXPath::name(pathname),FXPath::directory(pathname));	
-   	if(attrdlg->execute(PLACEMENT_SCREEN))
+   	if(attrdlg->execute(PLACEMENT_OWNER))
         list->setDirectory(pathname,TRUE);
     delete attrdlg;
    	return 1;
@@ -820,6 +820,8 @@ long DirPanel::onCmdAddToArch(FXObject* o,FXSelector,void*)
             cmd="tar -zcvf "+archive+" ";
 		else if (ext2=="tar.bz2")
             cmd="tar -jcvf "+archive+" ";
+		else if (ext2=="tar.xz")
+            cmd="tar -Jcvf "+archive+" ";
 		else if (ext2=="tar.z")
            	cmd="tar -Zcvf "+archive+" ";
 		else if (ext1=="tar")
@@ -828,22 +830,22 @@ long DirPanel::onCmdAddToArch(FXObject* o,FXSelector,void*)
 			cmd="gzip -v ";				
 		else if (ext1=="tgz")
             cmd="tar -zcvf "+archive+" ";
+		else if (ext1=="taz")
+            cmd="tar -Zcvf "+archive+" ";
 		else if (ext1=="bz2")
 			cmd="bzip2 -v ";				
+		else if (ext1=="xz")
+			cmd="xz -v ";				
 		else if (ext1=="tbz2")
             cmd="tar -jcvf "+archive+" ";
+		else if (ext1=="txz")
+            cmd="tar -Jcvf "+archive+" ";
 		else if (ext1=="z")
             cmd="compress -v ";
 		else if (ext1=="zip")
             cmd="zip -r "+archive+" ";
 		else if (ext1=="7z")
             cmd="7z a "+archive+" ";
-		else if (ext1=="rar")
-            cmd="rar a "+archive+" ";
-		else if (ext1=="lzh")
-            cmd="lha a "+archive+" ";
-		else if (ext1=="arj")
-            cmd="arj a -r "+archive+" ";
 		
 		// Default archive format
 		else
@@ -1403,6 +1405,7 @@ long DirPanel::onCmdDirMan(FXObject* sender,FXSelector sel,void* ptr)
 		if (operationdialog==NULL)
 			operationdialog=new BrowseInputDialog(this,"","",title,_("To:"),icon,BROWSE_INPUT_FOLDER);
 		operationdialog->setTitle(title);
+		operationdialog->setIcon(icon);
 		operationdialog->setMessage(message);
 		operationdialog->setText(target);
 		operationdialog->CursorEnd();
@@ -1844,7 +1847,7 @@ long DirPanel::onCmdDirDelete(FXObject*,FXSelector,void*)
 		FXString msg;
 		msg.format(_("Folder %s is write-protected, definitively delete it anyway?"),pathname.text());
 		MessageBox box(this,_("Confirm Delete"),msg,errorbigicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);        	
-		FXuint answer=box.execute(PLACEMENT_SCREEN);
+		FXuint answer=box.execute(PLACEMENT_OWNER);
 		if(answer == BOX_CLICKED_OK)
 		{
 			f->showProgressDialog();
@@ -1938,7 +1941,7 @@ long DirPanel::onCmdDirTrash(FXObject*,FXSelector,void*)
 		FXString str;
 		str.format(_("Folder %s is write-protected, move it to trash can anyway?"),pathname.text());
 		MessageBox box(this,_("Confirm Trash"),str,errorbigicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);        	
-		FXuint answer=box.execute(PLACEMENT_SCREEN);
+		FXuint answer=box.execute(PLACEMENT_OWNER);
 		if(answer == BOX_CLICKED_OK)
 		{
 			// Allow progress dialog
