@@ -73,7 +73,7 @@ File::File(FXWindow *owner, FXString title, const FXuint operation):DialogBox(ow
 	r=FXREDVAL(fgcolor);                                                     
 	g=FXGREENVAL(fgcolor);                                                   
 	b=FXBLUEVAL(fgcolor);
-	l=0.3*r+0.59*g+0.11*b;                                                                                  
+	l=(FXuint)(0.3*r+0.59*g+0.11*b);                                                                                  
 	if (l<150)
 		textaltcolor=FXRGB(255,255,255);
 	else
@@ -83,7 +83,7 @@ File::File(FXWindow *owner, FXString title, const FXuint operation):DialogBox(ow
 	r=FXREDVAL(bgcolor);                                                     
 	g=FXGREENVAL(bgcolor);                                                   
 	b=FXBLUEVAL(bgcolor);
-	l=0.3*r+0.59*g+0.11*b;                                                                                  
+	l=(FXuint)(0.3*r+0.59*g+0.11*b);                                                                                  
 	if (l<150)
 		textcolor=FXRGB(255,255,255);
 	else
@@ -180,6 +180,9 @@ File::File(FXWindow *owner, FXString title, const FXuint operation):DialogBox(ow
 		overwrite_all=TRUE;
 		skip_all=FALSE;
 	}
+
+	// Error message box
+	mbox=new MessageBox(this,_("Error"),"",errorbigicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);   
 }
 
 // Destructor
@@ -187,6 +190,7 @@ File::~File()
 {
 	getApp()->removeTimeout(this,File::ID_TIMEOUT);
 	delete progressbar;
+	delete mbox;
 }
 
 
@@ -313,7 +317,7 @@ FXuint File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
 	
 	// Overwrite dialog
 	OverwriteBox* dlg = new OverwriteBox(this,_("Confirm Overwrite"),msg);
-	FXuint answer=dlg->execute(PLACEMENT_SCREEN);
+	FXuint answer=dlg->execute(PLACEMENT_CURSOR);
 	delete dlg;
 	restartTimeout();
 
@@ -322,7 +326,7 @@ FXuint File::getOverwriteAnswer(FXString srcpath, FXString tgtpath)
 
 
 // Copy ordinary file
-FXbool File::copyfile(const FXString& source, const FXString& target, const FXbool preserve_date)
+FXint File::copyfile(const FXString& source, const FXString& target, const FXbool preserve_date)
 {
 	FXString destfile;
 	FXuchar buffer[32768];
@@ -356,11 +360,14 @@ FXbool File::copyfile(const FXString& source, const FXString& target, const FXbo
                     if(nread<0)
 					{
 						forceTimeout();
-						FXuint answer;
+
+						FXString str;
 						if (errcode)
-							answer=MessageBox::error(this,BOX_OK_CANCEL,_("Error"),_("Can't copy file %s: %s"),target.text(),strerror(errcode));
+							str.format(_("Can't copy file %s: %s"),target.text(),strerror(errcode));		
 						else
-							answer=MessageBox::error(this,BOX_OK_CANCEL,_("Error"),_("Can't copy file %s"),target.text());
+							str.format(_("Can't copy file %s"),target.text());
+						mbox->setText(str);
+						FXuint answer=mbox->execute(PLACEMENT_CURSOR);
 
 						restartTimeout();
 						if(answer == BOX_CLICKED_CANCEL)
@@ -407,11 +414,14 @@ FXbool File::copyfile(const FXString& source, const FXString& target, const FXbo
                     if(nwritten<0)
 					{
 						forceTimeout();
-						FXuint answer;
+
+						FXString str;
 						if (errcode)
-							answer=MessageBox::error(this,BOX_OK_CANCEL,_("Error"),_("Can't copy file %s: %s"),target.text(),strerror(errcode));
+							str.format(_("Can't copy file %s: %s"),target.text(),strerror(errcode));		
 						else
-							answer=MessageBox::error(this,BOX_OK_CANCEL,_("Error"),_("Can't copy file %s"),target.text());
+							str.format(_("Can't copy file %s"),target.text());
+						mbox->setText(str);
+						FXuint answer=mbox->execute(PLACEMENT_CURSOR);
 
 						restartTimeout();
 						if(answer == BOX_CLICKED_CANCEL)
@@ -437,12 +447,14 @@ FXbool File::copyfile(const FXString& source, const FXString& target, const FXbo
 					if (rc)
 					{
 						forceTimeout();
-						FXuint answer;
+
+						FXString str;
 						if (errcode)
-							answer=MessageBox::error(this,BOX_OK_CANCEL,_("Error"),_("Can't preserve date when copying file %s : %s"),target.text(),strerror(errcode));
+							str.format(_("Can't preserve date when copying file %s : %s"),target.text(),strerror(errcode));		
 						else
-							answer=MessageBox::error(this,BOX_OK,_("Error"),_("Can't preserve date when copying file %s"),target.text());
-					
+							str.format(_("Can't preserve date when copying file %s"),target.text());
+						mbox->setText(str);
+						FXuint answer=mbox->execute(PLACEMENT_CURSOR);
 						
 						restartTimeout();
 						if(answer == BOX_CLICKED_CANCEL)
@@ -469,12 +481,37 @@ FXbool File::copyfile(const FXString& source, const FXString& target, const FXbo
         }
         ::close(src);
     }
+
+	// File cannot be opened
+ 	else
+ 	{
+		forceTimeout();
+		FXint errcode=errno;
+
+		FXString str;
+		if (errcode)
+			str.format(_("Can't copy file %s: %s"),target.text(),strerror(errcode));		
+		else
+			str.format(_("Can't copy file %s"),target.text());
+		mbox->setText(str);
+		FXuint answer=mbox->execute(PLACEMENT_CURSOR);
+
+		restartTimeout();
+		if(answer == BOX_CLICKED_CANCEL)
+		{
+			::close(src);
+			cancelled=TRUE;
+			return FALSE;
+		}
+		ok=-1; // Prevent displaying an error message
+		       // in the calling function			
+	}
     return ok;
 }
 
 
 // Copy directory
-FXbool File::copydir(const FXString& source,const FXString& target,struct stat& parentinfo,inodelist* inodes, const FXbool preserve_date)
+FXint File::copydir(const FXString& source,const FXString& target,struct stat& parentinfo,inodelist* inodes, const FXbool preserve_date)
 {
     DIR *dirp;
     struct dirent *dp;
@@ -483,11 +520,8 @@ FXbool File::copydir(const FXString& source,const FXString& target,struct stat&
     inodelist *in,inode;
     FXString destfile,oldchild,newchild;
 
-	// If destination is an existing directory
-	if(::isDirectory(target))
-		destfile=target+PATHSEPSTRING+FXPath::name(source);
-	else
-		destfile=target;
+	// Destination file
+	destfile=target;
 
     // See if visited this inode already
     for(in=inodes; in; in=in->next)
@@ -544,8 +578,9 @@ FXbool File::copydir(const FXString& source,const FXString& target,struct stat&
 					else
 						str.format(_("Can't copy file %s : Permission denied"),oldchild.text());
        				forceTimeout();
-					MessageBox box(this,_("Error"),str,errorbigicon,BOX_OK_CANCEL|DECOR_TITLE|DECOR_BORDER);   
-					FXuint answer=box.execute(PLACEMENT_SCREEN);
+					mbox->setText(str);
+					FXuint answer=mbox->execute(PLACEMENT_CURSOR);
+
 					restartTimeout();
 					if(answer == BOX_CLICKED_CANCEL)
 					{
@@ -574,11 +609,14 @@ FXbool File::copydir(const FXString& source,const FXString& target,struct stat&
 			if (rc)
 			{
 				forceTimeout();
-				FXuint answer;
+				FXString str;
 				if (errcode)
-					answer=MessageBox::error(this,BOX_OK_CANCEL,_("Error"),_("Can't preserve date when copying folder %s : %s"),target.text(),strerror(errcode));
+					str.format(_("Can't preserve date when copying folder %s : %s"),target.text(),strerror(errcode));		
 				else
-					answer=MessageBox::error(this,BOX_OK_CANCEL,_("Error"),_("Can't preserve date when copying folder %s"),target.text());
+					str.format(_("Can't preserve date when copying folder %s"),target.text());
+				mbox->setText(str);
+				FXuint answer=mbox->execute(PLACEMENT_CURSOR);
+
 				restartTimeout();
 				if(answer == BOX_CLICKED_CANCEL)
 				{
@@ -596,34 +634,42 @@ FXbool File::copydir(const FXString& source,const FXString& target,struct stat&
 
 
 // Recursive copy
-FXbool File::copyrec(const FXString& source,const FXString& target,inodelist* inodes, const FXbool preserve_date)
+FXint File::copyrec(const FXString& source,const FXString& target,inodelist* inodes, const FXbool preserve_date)
 {
     struct stat linfo1, linfo2;
 	
     // Source file or directory does not exist
     if(lstatrep(source.text(),&linfo1)!=0)
         return FALSE;
-
+    
     // If target is not a directory, remove it if allowed
     if(lstatrep(target.text(),&linfo2)==0)
     {
         if(!S_ISDIR(linfo2.st_mode))
         {
-            if(!(overwrite|overwrite_all))
-                return FALSE;
+			if(!(overwrite|overwrite_all))
+               return FALSE;
             if(::unlink(target.text())!=0)
-                return FALSE;
+               return FALSE;
         }
     }
 
 	// Source is directory: copy recursively
     if(S_ISDIR(linfo1.st_mode))
         return File::copydir(source,target,linfo1,inodes,preserve_date);
-
+   
     // Source is regular file: copy block by block
     if(S_ISREG(linfo1.st_mode))
         return File::copyfile(source,target,preserve_date);
 
+ 	// Remove target if it already exists
+ 	if (::exists(target))
+ 	{
+ 		FXint ret=File::remove(target);
+ 		if (!ret)
+ 			return FALSE;
+	}
+
     // Source is fifo: make a new one
     if(S_ISFIFO(linfo1.st_mode))
         return mkfifo(target.text(),linfo1.st_mode);
@@ -635,7 +681,7 @@ FXbool File::copyrec(const FXString& source,const FXString& target,inodelist* in
     // Source is symbolic link: make a new one
     if(S_ISLNK(linfo1.st_mode))
     {
-        FXString lnkfile=readlink(source);
+		FXString lnkfile=::readLink(source);
         return ::symlink(lnkfile.text(),target.text())==0;
     }
 
@@ -646,7 +692,9 @@ FXbool File::copyrec(const FXString& source,const FXString& target,inodelist* in
 
 
 // Copy file (with progress dialog)
-FXbool File::copy(const FXString& source, const FXString& target, const FXbool confirm_dialog, const FXbool preserve_date)
+// Return  0 to allow displaying an error message in the calling routine
+// Return -1 to prevent displaying an error message in the calling routine
+FXint File::copy(const FXString& source, const FXString& target, const FXbool confirm_dialog, const FXbool preserve_date)
 {
 	FXString targetfile;
 
@@ -655,15 +703,15 @@ FXbool File::copy(const FXString& source, const FXString& target, const FXbool c
 	{
 		forceTimeout();
 		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s doesn't exist"), source.text());
-		return FALSE;
+		return -1;
 	}
 
 	// Source and target are identical
 	if (::identical(target,source))
 	{
 		forceTimeout();
-		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s is identical to target"), target.text());
-		return FALSE;
+		MessageBox::error(this,BOX_OK,_("Error"),_("Destination %s is identical to source"), target.text());
+		return -1;
 	}
 
 	// Target is an existing directory
@@ -676,8 +724,8 @@ FXbool File::copy(const FXString& source, const FXString& target, const FXbool c
 	if (::identical(targetfile,source))
 	{
 		forceTimeout();
-		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s is identical to target"), targetfile.text());			
-		return FALSE;
+		MessageBox::error(this,BOX_OK,_("Error"),_("Destination %s is identical to source"), targetfile.text());			
+		return -1;
 	}
 
 	// Target already exists
@@ -698,6 +746,7 @@ FXbool File::copy(const FXString& source, const FXString& target, const FXbool c
 				// Cancel
 				case 0:
 					forceTimeout();
+					cancelled=TRUE;
 					return FALSE;
 					break;
 				
@@ -724,21 +773,26 @@ FXbool File::copy(const FXString& source, const FXString& target, const FXbool c
 		}
 		if(!(overwrite | overwrite_all) | skip_all)
 			return TRUE;
-
-		if (File::remove(targetfile)==FALSE)
-		{
-			forceTimeout();
-			return FALSE;
+				
+		// Remove targetfile if source is not a directory
+		if (!::isDirectory(source))
+		{ 
+			if (File::remove(targetfile)==FALSE)
+			{
+				forceTimeout();
+				return FALSE;
+			}
 		}	
 	}
 
 	// Copy file or directory
 	return File::copyrec(source,targetfile,NULL,preserve_date);
+
 }
 
 
 // Remove file or directory (with progress dialog)
-FXbool File::remove(const FXString& file)
+FXint File::remove(const FXString& file)
 {
 	FXString dirname;
     struct stat linfo;
@@ -798,10 +852,25 @@ FXbool File::remove(const FXString& file)
             }
 			if (rmdir(file.text())==-1)
 			{
+				FXint errcode=errno;
 				forceTimeout();
-				MessageBox::error(this,BOX_OK,_("Error"),_("Can't delete folder %s"), file.text());
-				restartTimeout();			
-				return FALSE;
+
+				FXString str;
+				if (errcode)
+					str.format(_("Can't delete folder %s: %s"),file.text(),strerror(errcode));		
+				else
+					str.format(_("Can't delete folder %s"),file.text());
+				mbox->setText(str);
+				FXuint answer=mbox->execute(PLACEMENT_CURSOR);
+
+				restartTimeout();
+				if(answer == BOX_CLICKED_CANCEL)
+				{
+					cancelled=TRUE;
+					return FALSE;
+				}
+				return -1; // To prevent displaying an error message
+				           // in the calling function					
 			}
 			else
 				return TRUE;
@@ -834,10 +903,25 @@ FXbool File::remove(const FXString& file)
 			}
 			if (::unlink(file.text())==-1)
 			{
+				FXint errcode=errno;
 				forceTimeout();
-				MessageBox::error(this,BOX_OK,_("Error"),_("Can't delete file %s"), file.text());	
-				restartTimeout();		
-				return FALSE;
+
+				FXString str;
+				if (errcode)
+					str.format(_("Can't delete file %s: %s"),file.text(),strerror(errcode));			
+				else
+					str.format(_("Can't delete file %s"),file.text());
+				mbox->setText(str);
+				FXuint answer=mbox->execute(PLACEMENT_CURSOR);
+
+				restartTimeout();
+				if(answer == BOX_CLICKED_CANCEL)
+				{
+					cancelled=TRUE;
+					return FALSE;
+				}
+				return -1; // To prevent displaying an error message
+				           // in the calling function					
 			}
 			else
 				return TRUE;
@@ -848,20 +932,22 @@ FXbool File::remove(const FXString& file)
 
 
 // Rename a file or a directory (no progress dialog)
-FXbool File::rename(const FXString& source, const FXString& target)
+// Return  0 to allow displaying an error message in the calling routine
+// Return -1 to prevent displaying an error message in the calling routine
+FXint File::rename(const FXString& source, const FXString& target)
 {
 	// Source doesn't exist
     if(!::exists(source))
 	{
 		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s doesn't exist"), source.text());
-		return FALSE;
+		return -1;
 	}
 			
 	// Source and target are identical
 	if (::identical(target,source))
 	{
-		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s is identical to target"), target.text());
-		return FALSE;
+		MessageBox::error(this,BOX_OK,_("Error"),_("Destination %s is identical to source"), target.text());
+		return -1;
 	}
 
 	// Target already exists
@@ -909,12 +995,13 @@ FXbool File::rename(const FXString& source, const FXString& target)
 		return TRUE;
 	if(errno!=EXDEV)
 	{
+		forceTimeout();
 		MessageBox::error(this,BOX_OK,_("Error"),_("Can't rename to target %s"), target.text());	
 		return FALSE;
 	}
 
 	// If files are on different file systems, use the copy/delete scheme and preserve the original date
-	FXbool ret=this->copy(source,target,FALSE,TRUE);
+	FXint ret=this->copy(source,target,FALSE,TRUE);
 	if (ret)
 		return (remove(source.text())==TRUE);
 	else
@@ -923,22 +1010,34 @@ FXbool File::rename(const FXString& source, const FXString& target)
 
 
 // Move files
-FXbool File::move(const FXString& source,const FXString& target,const FXbool restore)
+// Return  0 to allow displaying an error message in the calling routine
+// Return -1 to prevent displaying an error message in the calling routine
+FXint File::move(const FXString& source,const FXString& target,const FXbool restore)
 {
 	// Source doesn't exist
 	if(!::exists(source))
 	{
 		forceTimeout();
 		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s doesn't exist"), source.text());
-		return FALSE;
+		return -1;
 	}
 
 	// Source and target are identical
 	if (identical(target,source))
 	{
 		forceTimeout();
-		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s is identical to target"), target.text());
-		return FALSE;
+		MessageBox::error(this,BOX_OK,_("Error"),_("Destination %s is identical to source"), target.text());
+		return -1;
+	}
+
+	// Source path is included into target path
+	FXString str=source + PATHSEPSTRING;
+	if (target.left(str.length()) == str)
+	{
+		forceTimeout();
+		MessageBox::error(this,BOX_OK,_("Error"),_("Target %s is a sub-folder of source"),target.text());
+		return -1;
+		
 	}
 
 	// Target is an existing directory (don't do this in the restore case)
@@ -952,8 +1051,8 @@ FXbool File::move(const FXString& source,const FXString& target,const FXbool res
 	if (::identical(targetfile,source))
 	{
 		forceTimeout();
-		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s is identical to target"), target.text());
-		return FALSE;
+		MessageBox::error(this,BOX_OK,_("Error"),_("Destination %s is identical to source"), target.text());
+		return -1;
 	}
 
 	// Force timeout checking for progress dialog
@@ -984,6 +1083,7 @@ FXbool File::move(const FXString& source,const FXString& target,const FXbool res
 				// Cancel
 				case 0:
 					forceTimeout();
+					cancelled=TRUE;
 					return FALSE;
 					break;
 				
@@ -1027,15 +1127,18 @@ FXbool File::move(const FXString& source,const FXString& target,const FXbool res
 	// This should only work for files that are on the same file system
 	if (::rename(source.text(),targetfile.text())==0)
 		return TRUE;
+/*
 	if(errno!=EXDEV)
 	{
 		forceTimeout();
 		MessageBox::error(this,BOX_OK,_("Error"),_("Can't rename to target %s"), targetfile.text());
 		return FALSE;
 	}
+*/
+	targetfile=FXPath::directory(targetfile);
 
 	// If files are on different file systems, use the copy/delete scheme and preserve the original date
-	FXbool ret=this->copy(source,targetfile,FALSE,TRUE);
+	FXint ret=this->copy(source,targetfile,FALSE,TRUE);
 	if (ret)
 		return (remove(source.text())==TRUE);
 	else
@@ -1044,22 +1147,24 @@ FXbool File::move(const FXString& source,const FXString& target,const FXbool res
 
 
 // Symbolic Link file (no progress dialog)
-FXbool File::symlink(const FXString& source,const FXString& target)
+// Return  0 to allow displaying an error message in the calling routine
+// Return -1 to prevent displaying an error message in the calling routine
+FXint File::symlink(const FXString& source,const FXString& target)
 {
 	// Source doesn't exist
     if(!::exists(source))
 	{
 		forceTimeout();
 		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s doesn't exist"), source.text());
-		return FALSE;
+		return -1;
 	}
 			
 	// Source and target are identical
 	if (::identical(target,source))
 	{
 		forceTimeout();
-		MessageBox::error(this,BOX_OK,_("Error"),_("Source %s is identical to target"), target.text());
-		return FALSE;
+		MessageBox::error(this,BOX_OK,_("Error"),_("Destination %s is identical to source"), target.text());
+		return -1;
 	}
 
 	// Target is an existing directory
@@ -1111,7 +1216,16 @@ FXbool File::symlink(const FXString& source,const FXString& target)
     
 	// Create symbolic link using the standard C function
 	errno=0;
-	FXint ret=::symlink(source.text(),targetfile.text());
+
+	// Use the relative path for the symbolic link
+	FXString relativepath;
+	if (::exists(target) && ::isDirectory(target))
+		relativepath=FXPath::relative(target,source);
+	else
+		relativepath=FXPath::relative(FXPath::directory(target),source);
+	
+	FXint ret=::symlink(relativepath.text(),targetfile.text());
+
 	FXint errcode=errno;	
 	if (ret==0)
 		return TRUE;
@@ -1470,7 +1584,7 @@ FXint File::archive(const FXString name, const FXString cmd)
 			FXString msg;
 			msg.format(_("File %s already exists. Overwrite?"),name.text());
        		OverwriteBox* dlg = new OverwriteBox(this,_("Confirm Overwrite"),msg);
-       		FXuint answer=dlg->execute(PLACEMENT_SCREEN);
+       		FXuint answer=dlg->execute(PLACEMENT_CURSOR);
 			delete dlg;
        		switch(answer)
        		{
@@ -1554,7 +1668,7 @@ FXint File::mount(const FXString dir, const FXString msg, const FXString cmd, co
 	snprintf(text,sizeof(text)-1,"%s",buf.text());
 	
 	// Close the stream
-	if(pclose(pcmd) && strcmp(text,"")!=0)
+	if(pclose(pcmd)==-1 && strcmp(text,"")!=0)
 	{
 		MessageBox::error(this,BOX_OK,_("Error"),"%s",text);
 		return -1;
