@@ -4,6 +4,7 @@
 
 #include <fx.h>
 #include "DialogBox.h"
+#include "MessageBox.h"
 
 
 // File operations
@@ -63,9 +64,9 @@ protected:
     long fullread(FXint fd, FXuchar* ptr, long len);
     long fullwrite(FXint fd, const FXuchar* ptr, long len);
 	FXuint getOverwriteAnswer(FXString, FXString);
-    FXbool copyfile(const FXString& source, const FXString& target, const FXbool preserve_date);
-	FXbool copyrec(const FXString& source,const FXString& target,inodelist* inodes, const FXbool preserve_date);
-    FXbool copydir(const FXString& source,const FXString& target,struct stat& parentstatus,inodelist* inodes, const FXbool preserve_date);
+    FXint copyfile(const FXString& source, const FXString& target, const FXbool preserve_date);
+	FXint copyrec(const FXString& source,const FXString& target,inodelist* inodes, const FXbool preserve_date);
+    FXint copydir(const FXString& source,const FXString& target,struct stat& parentstatus,inodelist* inodes, const FXbool preserve_date);
     FXint rchmod(FXchar* path, FXchar* file, mode_t mode, const FXbool dironly, const FXbool fileonly);
     FXint rchown(FXchar* path, FXchar* file, uid_t uid, gid_t gid, const FXbool dironly, const FXbool fileonly);
     FXLabel *uplabel;
@@ -76,6 +77,7 @@ protected:
 	FXbool overwrite_all;
 	FXbool skip_all;
 	FXbool cancelled;
+	MessageBox *mbox;	
 public:
     File()
     {}
@@ -105,11 +107,11 @@ public:
 		restartTimeout();
 	}
 
-	FXbool copy(const FXString& source, const FXString& target, const FXbool confirm_dialog=TRUE, const FXbool preserve_date=TRUE);
-    FXbool rename(const FXString& source, const FXString& target);
-    FXbool move(const FXString& source, const FXString& target, const FXbool restore=FALSE);
-    FXbool symlink(const FXString& source, const FXString& target);
-    FXbool remove(const FXString& file);
+	FXint copy(const FXString& source, const FXString& target, const FXbool confirm_dialog=TRUE, const FXbool preserve_date=TRUE);
+    FXint rename(const FXString& source, const FXString& target);
+    FXint move(const FXString& source, const FXString& target, const FXbool restore=FALSE);
+    FXint symlink(const FXString& source, const FXString& target);
+    FXint remove(const FXString& file);
 
     FXint chmod(FXchar* path, FXchar* file, mode_t mode, const FXbool rec, const FXbool dironly=FALSE, const FXbool fileonly=FALSE);
 	FXint chown(FXchar* path, FXchar *file, uid_t uid, gid_t gid, const FXbool rec, const FXbool dironly=FALSE, const FXbool fileonly=FALSE);
