@@ -25,20 +25,26 @@ class FXAPI IconDict : public FXDict
     FXDECLARE(IconDict)
 private:
     FXApp        *app;            // Application object
+  	FXIconSource *source;         // Icon source
     FXString      path;           // Where to search icons
 protected:
-    IconDict()
-    {}
+  	IconDict():source(NULL)
+  	{}
     virtual void *createData(const void*);
     virtual void deleteData(void*);
 private:
     IconDict(const IconDict&);
     IconDict &operator=(const IconDict&);
 
+public:
+
+  // Default icon search path
+	static const FXchar defaultIconPath[];
+
 public:
 
     // Construct an icon dictionary, with given path
-    IconDict(FXApp* a,const FXString& p=DEFAULTICONPATH);
+    IconDict(FXApp* a,const FXString& p=defaultIconPath);
 
     // Get application
     FXApp* getApp() const
@@ -46,6 +52,18 @@ public:
         return app;
     }
 
+  	// Change icon source
+  	void setIconSource(FXIconSource *src)
+  	{
+  		source=src;
+  	}
+
+  	// Return icon source
+  	FXIconSource* getIconSource() const
+  	{
+  		return source;
+  	}
+
     // Set icon search path
     void setIconPath(const FXString& p)
     {
@@ -78,6 +96,12 @@ public:
         return (FXIcon*)FXDict::find(name);
     }
 
+	// Save to stream
+	virtual void save(FXStream& store) const;
+
+	// Load from stream
+	virtual void load(FXStream& store);
+    
     // Destructor
     virtual ~IconDict();
 };
@@ -135,6 +159,19 @@ public:
         return app;
     }
 
+
+	// Change icon dictionary
+  	void setIconDict(IconDict *icns)
+  	{
+  		icons=icns;
+  	}
+
+  	// Return icon dictionary
+  	IconDict* getIconDict() const
+  	{
+  		return icons;
+  	}
+
     // Set icon search path
     void setIconPath(const FXString& path);
 
