@@ -31,7 +31,6 @@ protected:
     FXString 		name;
 	FXbool			ctrlkey;
 	FXbool			selmult;
-	FXString		homelocation;
 	FXString		trashlocation;
 	FXString		trashfileslocation;
 	FXString		trashinfolocation;
@@ -51,7 +50,7 @@ protected:
 	BrowseInputDialog* operationdialogsingle;
 	BrowseInputDialog* operationdialogmultiple;
 	FXbool			paste;
-	FXbool 			ctrlflag;			// Flag to select the right click control menu
+	FXbool 			ctrl;			    // Flag to select the right click control menu
 	FXbool			shiftf10;           // Flag indicating that Shift-F10 was pressed 
 	TextLabel*		pathtext;
 	FXbool			isactive;
@@ -75,6 +74,7 @@ FilePanel(FXWindow *owner, const FXchar*,FXComposite*, DirPanel*, FXuint name_si
     void Next(FilePanel*);
 	void updateLocation();
 	void showCorner(FXbool show);
+	void showActiveIcon(FXbool show);
 	enum
 	{
         ID_FILELIST=FXVerticalFrame::ID_LAST,
