@@ -12,6 +12,7 @@
 #include "FileDialog.h"
 #include "HistInputDialog.h"
 
+extern FXString homedir;
 
 // Object implementation
 FXIMPLEMENT(ComboBox,FXComboBox,NULL,0)
@@ -81,10 +82,7 @@ HistInputDialog::HistInputDialog(FXWindow* w,FXString inp,FXString message,FXStr
 		new FXLabel(contents,_("=> Warning: file name is not UTF-8 encoded!"),NULL,LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FILL_ROW);
 
 	// Initial directory for browsing
-	FXString homelocation=getenv("HOME");
-    if(homelocation=="")
-        homelocation=ROOTDIR;
-	initialdir=homelocation;
+	initialdir=homedir;
 }
 
 void HistInputDialog::create()
