@@ -16,13 +16,12 @@
 
 #include "xfedefs.h"
 #include "icons.h"
-#include "File.h"
+#include "xfeutils.h"
 #include "IconList.h"
 
 
-
 // Number of columns in detailed view, in the general case
-// NB : when the deletion date is displayed, one more column is added
+// NB : when the deletion date and original path are displayed, two more columns are added
 #define NUM_HEADERS 8
 
 
@@ -35,7 +34,7 @@
 #define ITEM_SPACE             192    // Default space for item name
 
 #define SELECT_MASK   (_ICONLIST_EXTENDEDSELECT|_ICONLIST_SINGLESELECT|_ICONLIST_BROWSESELECT|_ICONLIST_MULTIPLESELECT)
-#define ICONLIST_MASK (SELECT_MASK|_ICONLIST_MINI_ICONS|_ICONLIST_BIG_ICONS|_ICONLIST_COLUMNS|_ICONLIST_SEARCH|_ICONLIST_AUTOSIZE)
+#define ICONLIST_MASK (SELECT_MASK|_ICONLIST_MINI_ICONS|_ICONLIST_BIG_ICONS|_ICONLIST_COLUMNS|_ICONLIST_SEARCH|_ICONLIST_STANDARD|_ICONLIST_AUTOSIZE)
 
 extern FXuint single_click;
 extern FXbool file_tooltips;
@@ -263,7 +262,7 @@ void IconItem::drawDetails(IconList* list,FXDC& dc,FXint x,FXint y,FXint,FXint h
                 tw=font->getTextWidth(&label[beg],drw);
                 
 				// Right justify the file size column (second one in file list mode or third one in search list mode)
-				if ((!(options&_ICONLIST_SEARCH) && hi==1) || (options&_ICONLIST_SEARCH && hi==2))
+				if (!(options&_ICONLIST_STANDARD) && ((!(options&_ICONLIST_SEARCH) && hi==1) || (options&_ICONLIST_SEARCH && hi==2)))
 				{				
 					if (tw>space-20)
 					{
@@ -614,8 +613,13 @@ FXDEFMAP(IconList) IconListMap[]=
     FXMAPFUNC(SEL_CLICKED,0,IconList::onClicked),
     FXMAPFUNC(SEL_DOUBLECLICKED,0,IconList::onDoubleClicked),
     FXMAPFUNC(SEL_TRIPLECLICKED,0,IconList::onTripleClicked),
-    FXMAPFUNC(SEL_COMMAND,0,IconList::onCommand),
-    FXMAPFUNC(SEL_QUERY_TIP,0,IconList::onQueryTip),
+    
+	// Desactivated this one because of a conflict with KeybindingsBox
+	// I'll check if it is necessary
+	//FXMAPFUNC(SEL_COMMAND,0,IconList::onCommand),
+    
+	
+	FXMAPFUNC(SEL_QUERY_TIP,0,IconList::onQueryTip),
     FXMAPFUNC(SEL_QUERY_HELP,0,IconList::onQueryHelp),
     FXMAPFUNC(SEL_CHANGED,IconList::ID_HEADER_CHANGE,IconList::onHeaderChanged),
     FXMAPFUNC(SEL_CLICKED,IconList::ID_HEADER_CHANGE,IconList::onHeaderResize),
@@ -637,6 +641,7 @@ FXDEFMAP(IconList) IconListMap[]=
     FXMAPFUNC(SEL_COMMAND,FXWindow::ID_GETINTVALUE,IconList::onCmdGetIntValue),
     FXMAPFUNC(SEL_COMMAND,IconList::ID_AUTOSIZE,IconList::onCmdToggleAutosize),
     FXMAPFUNC(SEL_UPDATE,IconList::ID_AUTOSIZE,IconList::onUpdToggleAutosize),
+    FXMAPFUNC(SEL_COMMAND,IconList::ID_HEADER_CHANGE,IconList::onCmdHeaderClicked),
 };
 
 
@@ -648,11 +653,18 @@ FXIMPLEMENT(IconList,FXScrollArea,IconListMap,ARRAYNUMBER(IconListMap))
 
 // Icon List
 IconList::IconList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):
-        FXScrollArea(p,opts,x,y,w,h)
+                   FXScrollArea(p,opts,x,y,w,h)
 {
 	//autosize=opts&_ICONLIST_AUTOSIZE; // Workaround for a bug (?)
     flags|=FLAG_ENABLED;
-    header=new FXHeader(this,this,IconList::ID_HEADER_CHANGE,HEADER_TRACKING|HEADER_BUTTON|HEADER_RESIZE|FRAME_RAISED|FRAME_THICK);
+
+	// Headers look slightly different depending on the control theme 
+	FXbool use_clearlooks=getApp()->reg().readUnsignedEntry("SETTINGS","use_clearlooks",TRUE);
+	if (use_clearlooks)
+    	header=new FXHeader(this,this,IconList::ID_HEADER_CHANGE,HEADER_TRACKING|HEADER_BUTTON|HEADER_RESIZE|FRAME_RAISED);
+	else
+    	header=new FXHeader(this,this,IconList::ID_HEADER_CHANGE,HEADER_TRACKING|HEADER_BUTTON|HEADER_RESIZE|FRAME_RAISED|FRAME_THICK);
+
     target=tgt;
     message=sel;
     nrows=1;
@@ -667,14 +679,14 @@ IconList::IconList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint
     textColor=getApp()->getForeColor();
     selbackColor=getApp()->getSelbackColor();
     seltextColor=getApp()->getSelforeColor();
-
 	highlightColor=getApp()->reg().readColorEntry("SETTINGS","highlightcolor",FXRGB(238,238,238));
 
 	// Sort colors for detailed mode
+	FXColor listbackColor=getApp()->reg().readColorEntry("SETTINGS","listbackcolor",FXRGB(255,255,255));
 	FXuint R, G, B;
-	R=(FXuint)(DARKEN_SORT*FXREDVAL(backColor));
-	G=(FXuint)(DARKEN_SORT*FXGREENVAL(backColor));
-	B=(FXuint)(DARKEN_SORT*FXBLUEVAL(backColor));
+	R=(FXuint)(DARKEN_SORT*FXREDVAL(listbackColor));
+	G=(FXuint)(DARKEN_SORT*FXGREENVAL(listbackColor));
+	B=(FXuint)(DARKEN_SORT*FXBLUEVAL(listbackColor));
 	sortColor=FXRGB(R,G,B);
 	R=(FXuint)(DARKEN_SORT*FXREDVAL(highlightColor));
 	G=(FXuint)(DARKEN_SORT*FXGREENVAL(highlightColor));
@@ -693,14 +705,15 @@ IconList::IconList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint
     state=FALSE;
 	numsortheader=0;
 	count=0;
+	ignorecase=TRUE;
+	initheaderpct=TRUE;
+	allowTooltip=TRUE;
 }
 
 
 // Used to resize the headers relatively to the list width
 long IconList::onConfigure(FXObject*,FXSelector,void*)
 {
-	static FXint flag=0;
-
 	// Obtain the main window width
 	FXint width=(this->getShell())->getWidth();
 	
@@ -708,20 +721,27 @@ long IconList::onConfigure(FXObject*,FXSelector,void*)
 	if (count==1)
 	{
 		// Initialize the relative header sizes
-		for (int hi=0; hi<getNumHeaders(); hi++)
+		for (FXint hi=0; hi<getNumHeaders(); hi++)
 			headerpct[hi]=(FXdouble)getHeaderSize(hi)/(FXdouble)width;
 	}
 
 	// Update the relative header sizes
 	if (relative_resize && count>=1)
 	{
-		if (flag==0 && getNumHeaders()==9)
+		// Initialize the extra header pcts if necessary
+		if (initheaderpct && getNumHeaders()==9)  // Search list, is it really necessary???
 		{
 			headerpct[8]=(FXdouble)getHeaderSize(8)/(FXdouble)width;
-			flag=1;
+			initheaderpct=FALSE;
+		}
+		if (initheaderpct && getNumHeaders()==10)
+		{
+			headerpct[8]=(FXdouble)getHeaderSize(8)/(FXdouble)width;
+			headerpct[9]=(FXdouble)getHeaderSize(9)/(FXdouble)width;
+			initheaderpct=FALSE;
 		}
 		FXint newhsize;
-		for (int hi=0; hi<getNumHeaders(); hi++)
+		for (FXint hi=0; hi<getNumHeaders(); hi++)
 		{
 			newhsize=(FXint)round(headerpct[hi]*width);
 			setHeaderSize(hi,newhsize);		
@@ -989,10 +1009,18 @@ void IconList::position(FXint x,FXint y,FXint w,FXint h)
 }
 
 
+// A header button was clicked : pass the message to the target
+long IconList::onCmdHeaderClicked(FXObject*,FXSelector,void* ptr)
+{
+    if (target && target->tryHandle(this,FXSEL(SEL_COMMAND,message),ptr));
+	return 1;
+}
+
+
 // Header subdivision has changed:- this is a bit tricky,
 // we want to update the content size w/o re-measuring the items...
-long IconList::onHeaderChanged(FXObject*,FXSelector,void*)
-{
+long IconList::onHeaderChanged(FXObject*,FXSelector,void* ptr)
+{	
 	// Obtain the main window width
 	FXint width=(this->getShell())->getWidth();
 
@@ -1258,17 +1286,6 @@ void* IconList::getItemData(FXint index) const
 }
 
 
-// True if item is selected
-FXbool IconList::isItemSelected(FXint index) const
-{
-    if (index<0 || items.no()<=index)
-    {
-        fxerror("%s::isItemSelected: index out of range.\n",getClassName());
-    }
-    return items[index]->isSelected();
-}
-
-
 // True if item is current
 FXbool IconList::isItemCurrent(FXint index) const
 {
@@ -1406,8 +1423,15 @@ FXint IconList::getItemAt(FXint x,FXint y)
 	
 	// Update the allowTooltip variable
 	allowTooltip=TRUE;
-	if (single_click==SINGLE_CLICK_DIR_FILE)
-		setDefaultCursor(getApp()->getDefaultCursor(DEF_HAND_CURSOR));
+	if (options&_ICONLIST_STANDARD)
+		allowTooltip=FALSE;
+
+	if (!(options&_ICONLIST_STANDARD) && (single_click==SINGLE_CLICK_DIR_FILE) )
+	{
+		// Don't change cursor while the wait cursor is displayed
+		if (::setWaitCursor(getApp(),QUERY_CURSOR)==0)
+			setDefaultCursor(getApp()->getDefaultCursor(DEF_HAND_CURSOR));
+	}
 		
 	if(options&(_ICONLIST_BIG_ICONS|_ICONLIST_MINI_ICONS))
 	{		
@@ -1434,7 +1458,10 @@ FXint IconList::getItemAt(FXint x,FXint y)
 		if (x==0 || x>header->getItemSize(0))
 		{
 			allowTooltip=FALSE;		
-			setDefaultCursor(getApp()->getDefaultCursor(DEF_ARROW_CURSOR));
+			
+			// Don't change cursor while the wait cursor is displayed
+			if (::setWaitCursor(getApp(),QUERY_CURSOR)==0)
+				setDefaultCursor(getApp()->getDefaultCursor(DEF_ARROW_CURSOR));
 		}
 		
 		y-=header->getDefaultHeight();
@@ -2112,8 +2139,9 @@ long IconList::onQueryTip(FXObject* sender,FXSelector sel,void* ptr)
 			FXString user=str.section('\t',5);
 			FXString group=str.section('\t',6);
 			FXString perms=str.section('\t',7);
-			FXString deldate=str.section('\t',8);
-			FXString pathname=str.section('\t',9);
+			FXString origpath=str.section('\t',8);
+			FXString deldate=str.section('\t',9);
+			FXString pathname=str.section('\t',10);
 
 			// Don't display tooltip for the dotdot directory
 			if (name=="..")
@@ -2135,8 +2163,11 @@ long IconList::onQueryTip(FXObject* sender,FXSelector sel,void* ptr)
 							   +_("Modified date: ")+date+"\n"+_("User: ")+user+" - "+_("Group: ")+group+"\n"
 							   +_("Permissions: ")+perms;
 					else
-						string=_("Name: ")+name+"\n"+_("Size in root: ")+size+"\n"+_("Type: ")+type+"\n"
-							   +_("Modified date: ")+date+"\n"+_("Deletion date: ")+deldate+"\n"
+						string=_("Name: ")+name+"\n"+
+							   +_("Original path: ")+origpath+"\n"
+							   +_("Size in root: ")+size+"\n"+_("Type: ")+type+"\n"
+							   +_("Modified date: ")+date+"\n"
+							   +_("Deletion date: ")+deldate+"\n"
 							   +_("User: ")+user+" - "+_("Group: ")+group+"\n"+_("Permissions: ")+perms;
 				}
 				// Regular file
@@ -2147,9 +2178,12 @@ long IconList::onQueryTip(FXObject* sender,FXSelector sel,void* ptr)
 							   +_("Modified date: ")+date+"\n"+_("User: ")+user+" - "+_("Group: ")+group
 							   +"\n"+_("Permissions: ")+perms;
 					else
-						string=_("Name: ")+name+"\n"+_("Size: ")+size+"\n"+_("Type: ")+type
-							   +"\n"+_("Modified date: ")+date+"\n"+_("Deletion date: ")+deldate
-							   +"\n"+_("User: ")+user+" - "+_("Group: ")+group+"\n"+_("Permissions: ")+perms;
+						string=_("Name: ")+name+"\n"+
+						       +_("Original path: ")+origpath+"\n"
+							   +_("Size: ")+size+"\n"+_("Type: ")+type
+							   +"\n"+_("Modified date: ")+date+"\n"
+							   +_("Deletion date: ")+deldate+"\n"
+							   +_("User: ")+user+" - "+_("Group: ")+group+"\n"+_("Permissions: ")+perms;
 						
 				}
 			}
@@ -2157,7 +2191,11 @@ long IconList::onQueryTip(FXObject* sender,FXSelector sel,void* ptr)
 			return 1;
 		}
 		else if(!allowTooltip)
-			setDefaultCursor(getApp()->getDefaultCursor(DEF_ARROW_CURSOR));
+		{
+			// Don't change cursor while the wait cursor is displayed
+			if (::setWaitCursor(getApp(),QUERY_CURSOR)==0)
+				setDefaultCursor(getApp()->getDefaultCursor(DEF_ARROW_CURSOR));
+		}
 	}
 
     return 0;
@@ -2245,8 +2283,8 @@ long IconList::onPaint(FXObject*,FXSelector,void* ptr)
                 for (c=clo; c<=chi; c++)
                 {
                     x=pos_x+c*itemSpace;
-                    index=(options&_ICONLIST_COLUMNS) ? ncols*r+c : nrows*c+r;
-                    dc.setForeground(backColor);
+                    index=(options&_ICONLIST_COLUMNS) ? ncols*r+c : nrows*c+r;					
+					dc.setForeground(backColor);
                     dc.fillRectangle(x,y,itemSpace,itemHeight);
                     if (index<items.no())
                     {
@@ -2456,7 +2494,7 @@ long IconList::onUpdShowMiniIcons(FXObject* sender,FXSelector,void*)
 long IconList::onCmdSelectAll(FXObject*,FXSelector,void*)
 {
     for (int i=0; i<items.no(); i++) selectItem(i,TRUE);
-	if (!(options&_ICONLIST_SEARCH))
+	if (!(options&_ICONLIST_SEARCH) && !(options&_ICONLIST_STANDARD))
 		deselectItem(0,TRUE);
     return 1;
 }
@@ -2474,7 +2512,7 @@ long IconList::onCmdDeselectAll(FXObject*,FXSelector,void*)
 long IconList::onCmdSelectInverse(FXObject*,FXSelector,void*)
 {
     for (int i=0; i<items.no(); i++) toggleItem(i,TRUE);
-	if (!(options&_ICONLIST_SEARCH))
+	if (!(options&_ICONLIST_SEARCH) && !(options&_ICONLIST_STANDARD))
 		deselectItem(0,TRUE);
    return 1;
 }
@@ -2836,9 +2874,15 @@ hop:
             return 0;
         if (!Ascii::isPrint(event->text[0]))
             return 0;
-        lookup.append(event->text);
+        lookup.append(event->text);				
         getApp()->addTimeout(this,ID_LOOKUPTIMER,getApp()->getTypingSpeed());
-        index=findItem(lookup,current,SEARCH_FORWARD|SEARCH_WRAP|SEARCH_PREFIX);
+		
+		// String lookup can be case insensitive now
+		if (ignorecase)
+			index=findItem(lookup,current,SEARCH_FORWARD|SEARCH_WRAP|SEARCH_PREFIX|SEARCH_IGNORECASE);
+		else
+			index=findItem(lookup,current,SEARCH_FORWARD|SEARCH_WRAP|SEARCH_PREFIX);
+		
         if (0<=index)
         {
             setCurrentItem(index,TRUE);
@@ -3801,6 +3845,13 @@ void IconList::setHelpText(const FXString& text)
 }
 
 
+// Set ignore case flag
+void IconList::setIgnoreCase(FXbool icase)
+{
+	ignorecase=icase;
+}
+
+
 // Save data
 void IconList::save(FXStream& store) const
 {
