@@ -37,6 +37,7 @@ private:
     MessageBox(const MessageBox&);
     MessageBox &operator=(const MessageBox&);
     void initialize(const FXString&,FXIcon*,FXuint,FXuint);
+    FXLabel* msg;
 public:
     long onCmdClicked(FXObject*,FXSelector,void*);
     long onCmdCancel(FXObject*,FXSelector,void*);
@@ -85,6 +86,18 @@ public:
     static FXuint information(FXWindow* owner,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
     static FXuint information(FXApp* app,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
 
+	// Get message text
+	FXString getText(void)
+	{
+		return msg->getText();
+	}
+	
+	// Set message text
+	void setText(FXString text)
+	{
+		msg->setText(text);
+	}
+
 };
 
 #endif
