@@ -277,7 +277,7 @@ long PathLinker::pathButtonPressed(FXObject * obj ,FXSelector sel ,void* ptr)
 	// Update the FileList and DirList directory
 	filelist->setDirectory(filePath);
 	if (dirlist)
-		dirlist->setDirectory(FXPath::directory(filePath),TRUE);
+		dirlist->setDirectory(filePath,TRUE);
 	
 	return 1;
 }
