@@ -905,7 +905,7 @@ long PreferencesBox::onCmdChangeKeyBindings(FXObject*,FXSelector,void*)
 	if (bindingsbox==NULL)
 		bindingsbox=new KeybindingsBox(this,glbBindingsDict,xfeBindingsDict,xfiBindingsDict,xfwBindingsDict);	
     
-	bindingsbox->execute(PLACEMENT_SCREEN);
+	bindingsbox->execute(PLACEMENT_OWNER);
 	
     return 1;
 }
