@@ -4,25 +4,26 @@
 #include <string.h>
 
 #include "DialogBox.h"
+#include "Keybindings.h"
 
 
 // Number of modifiable colors
-#define COLORS_NUM 9
+#define NUM_COLORS 11
 
 // Number of themes
-#define THEMES_NUM 13
+#define NUM_THEMES 13
 
 
 struct Theme
 {
     const char *name;
-    FXColor color[9];
+    FXColor color[NUM_COLORS];
     Theme()
     {
         name = "";
     };
     Theme(const char *n,FXColor base=0,FXColor bdr=0,FXColor bg=0,FXColor fg=0,
-	                    FXColor selbg=0,FXColor selfg=0, FXColor listbg=0, FXColor listfg=0, FXColor listhl=0)
+	                    FXColor selbg=0,FXColor selfg=0, FXColor listbg=0, FXColor listfg=0, FXColor listhl=0, FXColor pbarfg=0, FXColor attenfg=0)
     {
         name = strdup(n);
         color[0] = base;
@@ -35,10 +36,15 @@ struct Theme
 		color[7] = listfg;
  		color[7] = listfg;
   		color[8] = listhl;
+		color[9] = pbarfg;
+		color[10]= attenfg;
 	};
     FXbool operator != (const Theme&);
 };
 
+FXColor makeHiliteColorGradient(FXColor);
+FXColor makeShadowColorGradient(FXColor);
+
 class PreferencesBox : public DialogBox
 {
     FXDECLARE(PreferencesBox)
@@ -73,15 +79,18 @@ private:
     FXString    oldvideoviewer;
     FXString    oldaudioviewer;
     FXCheckButton  *autosave;
+    FXCheckButton  *savewinpos;
     FXCheckButton  *diropen;
     FXCheckButton  *fileopen;
     FXCheckButton  *filetooltips;
     FXCheckButton  *relativeresize;
     FXCheckButton  *showpathlink;
     FXCheckButton  *quit;
+    FXCheckButton  *rootmode;
     FXCheckButton  *trashcan;
     FXCheckButton  *trashbypass;
     FXCheckButton  *dnd;
+    FXCheckButton  *trashmv;
     FXCheckButton  *del;
     FXCheckButton  *del_emptydir;
     FXCheckButton  *overwrite;
@@ -92,8 +101,11 @@ private:
 	FXCheckButton  *show_mount;
 	FXCheckButton  *scroll;
 	FXCheckButton  *controls;
+#ifdef STARTUP_NOTIFICATION
+	FXCheckButton  *usesn;
+#endif
 	FXColorWell    *cwell;
-    Theme          Themes[THEMES_NUM];
+    Theme          Themes[NUM_THEMES];
     Theme          currTheme;
     Theme          currTheme_prev;
 	FXbool		   use_sudo;
@@ -101,6 +113,7 @@ private:
 	FXbool		   trashcan_prev;
 	FXbool		   trashbypass_prev;
 	FXbool		   autosave_prev;
+	FXbool		   savewinpos_prev;
 	FXbool         diropen_prev;
 	FXbool         fileopen_prev;
 	FXbool         filetooltips_prev;
@@ -110,11 +123,17 @@ private:
 	FXuint	       value_prev;
 	FXbool		   ask_prev;
 	FXbool		   dnd_prev;
+	FXbool		   trashmv_prev;
 	FXbool		   del_prev;
 	FXbool		   del_emptydir_prev;
 	FXbool		   overwrite_prev;
 	FXbool		   quit_prev;
-	FXbool		   controls_prev;
+	FXbool		   use_clearlooks;
+	FXbool		   use_clearlooks_prev;
+	FXbool         rootmode_prev;
+#ifdef STARTUP_NOTIFICATION
+	FXbool		   usesn_prev;
+#endif
 #if defined(linux)
 	FXbool		   mount_prev;
 	FXbool		   show_mount_prev;
@@ -122,6 +141,11 @@ private:
 	FXbool		   root_warning_prev;
 	FXuint		   themelist_prev;
 	FXbool		   smoothscroll_prev;
+	KeybindingsBox 		*bindingsbox;
+	FXStringDict		*glbBindingsDict;
+	FXStringDict		*xfeBindingsDict;
+	FXStringDict		*xfiBindingsDict;
+	FXStringDict		*xfwBindingsDict;
 public:
     enum
 	{
@@ -141,19 +165,24 @@ public:
         ID_THEME,
         ID_BROWSE_ICON_PATH,
 		ID_TRASH_BYPASS,
+		ID_CONFIRM_TRASH,
 		ID_CONFIRM_DEL_EMPTYDIR,
 		ID_SU_CMD,
 		ID_SUDO_CMD,
+		ID_STANDARD_CONTROLS,
+		ID_CLEARLOOKS_CONTROLS,
 		ID_WHEELADJUST,
 		ID_SINGLE_CLICK_FILEOPEN,
 		ID_FILE_TOOLTIPS,
 		ID_RELATIVE_RESIZE,
 		ID_SHOW_PATHLINK,
+		ID_CHANGE_KEYBINDINGS,
+		ID_RESTORE_KEYBINDINGS,
         ID_LAST
     };
 
 public:
-    PreferencesBox(FXWindow *win,FXColor listbackcolor=FXRGB(255,255,255), FXColor listforecolor=FXRGB(0,0,0), FXColor highlightcolor=FXRGB(238,238,238));
+    PreferencesBox(FXWindow *win,FXColor listbackcolor=FXRGB(255,255,255), FXColor listforecolor=FXRGB(0,0,0), FXColor highlightcolor=FXRGB(238,238,238),FXColor pbarcolor=FXRGB(0,0,255),FXColor attentioncolor=FXRGB(255,0,0));
     long onCmdAccept(FXObject*,FXSelector,void*);
     long onCmdBrowse(FXObject*,FXSelector,void*);
     long onCmdColor (FXObject*,FXSelector,void*);
@@ -162,7 +191,7 @@ public:
     long onCmdBrowsePath(FXObject*,FXSelector,void*);
 	long onCmdNormalFont(FXObject*,FXSelector,void*);
 	long onCmdTextFont(FXObject*,FXSelector,void*);
-	long onUpdTrashBypass(FXObject*,FXSelector,void*);
+	long onUpdTrash(FXObject*,FXSelector,void*);
 	long onUpdConfirmDelEmptyDir(FXObject*,FXSelector,void*);
 	long onCmdSuMode(FXObject*,FXSelector,void*);
 	long onUpdSuMode(FXObject*,FXSelector,void*);
@@ -171,6 +200,9 @@ public:
 	long onUpdSingleClickFileopen(FXObject*,FXSelector,void*);
 	FXuint execute(FXuint);
 	long onCmdCancel(FXObject*,FXSelector,void*);
-
+	long onCmdControls(FXObject*,FXSelector ,void*);
+	long onUpdControls(FXObject*,FXSelector,void*);
+	long onCmdChangeKeyBindings(FXObject*,FXSelector,void*);
+	long onCmdRestoreKeyBindings(FXObject*,FXSelector,void*);
 };
 #endif
