@@ -228,9 +228,10 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 
 	extension=file.rafter('.',1);
 	extension=extension.lower();
-	if (extension=="gz" || extension=="tgz" || extension=="tar" || extension=="bz2" ||
-		extension=="tbz2" || extension=="zip" || extension=="7z" || extension=="Z" ||
-		extension=="lzh" || extension=="rar" || extension=="ace" || extension=="arj")
+	if (extension=="gz" || extension=="tgz" || extension=="tar" || extension=="taz" || extension=="bz2"
+	    || extension=="tbz2" || extension =="xz" || extension=="txz" || extension=="zip"
+	    || extension=="7z" || extension=="Z" || extension=="lzh" || extension=="rar"
+	    || extension=="ace" || extension=="arj")
 	{
 		is_ar = TRUE; // archive
 		viewlbl = _("Extract:");
@@ -588,7 +589,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 #ifdef STARTUP_NOTIFICATION
 
 		sngroup=new FXGroupBox(generalframe,_("Startup Notification"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
-		snbutton=new FXCheckButton(sngroup,_("Disable startup notification for this file"),this,ID_SNDISABLE);
+		snbutton=new FXCheckButton(sngroup,_("Disable startup notification for this executable"),this,ID_SNDISABLE);
 
 		sndisable_prev=FALSE;
 		FXString snexcepts=getApp()->reg().readStringEntry("OPTIONS","startup_notification_exceptions","");
