@@ -22,9 +22,9 @@ public:
     TextWindow(FXApp* app, const FXString& name, FXint nblines, FXint nbcols);
     virtual ~TextWindow();
 	void setText(const FXchar*);
-	void appendText(const FXchar* str);
+	void appendText(const FXchar*);
 	void scrollToLastLine(void);
-	void setFont(FXFont* font);
+	void setFont(FXFont*);
 	FXint getLength(void);
 };
 
