@@ -42,6 +42,9 @@ FXbool file_tooltips;
 FXbool relative_resize;
 FXbool show_pathlink;
 FXbool save_win_pos;
+FXString homedir;
+FXString xdgconfighome;
+FXString xdgdatahome;
 
 
 // Hand cursor replacement
@@ -1817,8 +1820,18 @@ void XFileImage::saveConfig()
 
 	if (save_win_pos)
 	{
-		getApp()->reg().writeIntEntry("OPTIONS","xpos",getX());
-		getApp()->reg().writeIntEntry("OPTIONS","ypos",getY());
+		// Account for the Window Manager border size
+		XWindowAttributes xwattr;
+		if (XGetWindowAttributes((Display*)getApp()->getDisplay(),this->id(),&xwattr))
+		{
+			getApp()->reg().writeIntEntry("OPTIONS","xpos",getX()-xwattr.x);
+			getApp()->reg().writeIntEntry("OPTIONS","ypos",getY()-xwattr.y);
+		}
+		else
+		{
+			getApp()->reg().writeIntEntry("OPTIONS","xpos",getX());
+			getApp()->reg().writeIntEntry("OPTIONS","ypos",getY());
+		}
 	}
 
     // Width of tree
@@ -1969,6 +1982,17 @@ int main(int argc,char *argv[])
 	const char *vdrname = XFEVDRNAME;
 	FXbool loadicons;
 
+	// Get environment variables $HOME, $XDG_DATA_HOME and $XDG_CONFIG_HOME
+	homedir=FXSystem::getHomeDirectory();
+    if(homedir=="")
+        homedir=ROOTDIR;
+	xdgdatahome=getenv("XDG_DATA_HOME");
+    if(xdgdatahome=="")
+        xdgdatahome=homedir + PATHSEPSTRING DATAPATH;     
+	xdgconfighome=getenv("XDG_CONFIG_HOME");
+    if(xdgconfighome=="")
+        xdgconfighome=homedir + PATHSEPSTRING CONFIGPATH;
+
 #ifdef HAVE_SETLOCALE
 	// Set locale via LC_ALL.
 	setlocale (LC_ALL, "");
@@ -2054,7 +2078,7 @@ int main(int argc,char *argv[])
 	// Set display pathlinker flag according to the Xfe registry
 	show_pathlink=reg_xfe->readUnsignedEntry("SETTINGS","show_pathlinker",TRUE);
 	    
-    // Retain window position flag
+    // Get value of the window position flag
 	save_win_pos=reg_xfe->readUnsignedEntry("SETTINGS","save_win_pos",FALSE);
 
 	// Delete the Xfe registry
