@@ -68,7 +68,8 @@
     - Color themes (GNOME, KDE, Windows...)\n \
     - Icon themes (Xfe, GNOME, KDE, XFCE, Tango, Windows...)\n \
     - Control themes (Standard or Clearlooks like)\n \
-    - Create/Extract archives (tar, compress, zip, gzip, bzip2, lzh, rar, ace, arj and 7zip formats are supported)\n \
+    - Create archives (tar, compress, zip, gzip, bzip2, xz and 7zip formats are supported)\n \
+    - Extract archives (tar, compress, zip, gzip, bzip2, xz, lzh, rar, ace, arj and 7zip formats are supported)\n \
     - Tooltips with file properties\n \
     - Progress bars or dialogs for lengthy file operations\n \
     - Thumbnails image previews\n \
@@ -227,7 +228,18 @@
 \n \
  Default PNG icons are located in /usr/share/xfe/icons/xfe-theme or /usr/local/share/xfe/icons/xfe-theme, depending\n \
  on your installation. You can easily change the icon theme path in Preferences dialog.\n \
- \n \
+\n \
+\n \
+\n \
+  Non Latin based languages\n \
+  =-=-=-=-=-=-=-=-=-=-=-=-=\n \
+\n \
+ Xfe can display its user interface and also the file names in non latin character based languages, provided that you\n \
+ have selected a Unicode font that supports your character set. To select a suitable font, use the\n \
+ Edit / Preferences / Font menu item.\n \
+\n \
+ Multilingual Unicode TrueType fonts can be found at this address: http://www.slovo.info/unifonts.htm\n \
+\n \
 \n \
 \n \
   Tips\n \
@@ -287,7 +299,7 @@
  Many thanks to Maxim Baranov for his excellent X Win Commander and to all people that have provided useful\n \
  patches, translations, tests and advices.\n \
 \n \
- [Last revision: 4/03/2011]\n \
+ [Last revision: 6/04/2012]\n \
 \n \
  ")
 ;
