@@ -63,6 +63,9 @@ FXIcon* loadiconfile(FXApp *app, const FXString iconpath, const FXString iconnam
 				// Load it
 				icon->loadPixels(str);
 
+				// Create it
+				icon->create();
+
 				// Done
 				str.close();
 
