@@ -21,13 +21,6 @@
 #include "xfeutils.h"
 
 
-// Global variables
-#if defined(linux)
-extern FXStringDict* mtdevices;
-extern FXStringDict* updevices;
-#endif
-
-
 
 // Note : the original function from FXAccelTable is buggy!!
 // Parse accelerator from string
@@ -141,20 +134,34 @@ FXHotKey _parseAccel(const FXString& string)
 }
 
 
-// Check if the specified command can be found in exec path
-FXbool existCommand(FXString cmd)
+FXbool existCommand(const FXString cmd)
 {
 	struct stat linfo;
 
-	// If first character is '/' then cmd is an absolute path
-	if (cmd[0]==PATHSEPCHAR)
+	// Command file path
+	FXString cmdpath = cmd.before(' ');
+
+	// If first character is '/' then cmdpath is an absolute path
+	if (cmdpath[0]==PATHSEPCHAR)
 	{
-		// Check if command exists
-		if (!cmd.empty() && (lstatrep(cmd.text(),&linfo)==0))
+		// Check if command file name exists and is not a directory
+		if (!cmdpath.empty() && (lstatrep(cmdpath.text(),&linfo)==0) && !S_ISDIR(linfo.st_mode))
 			return TRUE;	
 	}
+
+	// If first character is '~' then cmdpath is a path relative to home directory
+	else if (cmdpath[0] == '~')
+	{
+		// Form command absolute path
+		cmdpath=FXSystem::getHomeDirectory() + cmdpath.after('~');
+		
+		// Check if command file name exists and is not a directory
+		if (!cmdpath.empty() && (lstatrep(cmdpath.text(),&linfo)==0) && !S_ISDIR(linfo.st_mode))
+			return TRUE;
+		
+	}
 	
-	// Simple command name or relative path
+	// Simple command name or path relative to the exec path
 	else
 	{
 		// Get exec path
@@ -172,14 +179,15 @@ FXbool existCommand(FXString cmd)
 					break;
 				
 				// Form command absolute path
-				path += PATHSEPSTRING + cmd.before(' ');			
-				
-				// Check if command exists
-				if (!path.empty() && (lstatrep(path.text(),&linfo)==0))
+				path += PATHSEPSTRING + cmdpath;	
+
+				// Check if command file name exists and is not a directory
+				if (!path.empty() && (lstatrep(path.text(),&linfo)==0) && !S_ISDIR(linfo.st_mode))
 					return TRUE;
 			}
 		}
     }
+
 	return FALSE;
 }
 
@@ -511,74 +519,6 @@ FXbool isUtf8(const FXchar* string, FXuint length)
 }
 
 
-// Replacement of the stat function
-inline FXint statrep(const FXchar* filename, struct stat* buf)
-{
-#if defined(linux)
-
-	static FXint ret;
-
-	// It's a mount point
-	if(mtdevices->find(filename))
-	{
-		// Mount point is down
-		if(streq(updevices->find(filename),"down"))
-			return -1;
-		
-		// Mount point is up
-		else
-		{
-			ret=stat(filename,buf);
-			if (ret==-1)
-			{
-				updevices->remove(filename);
-				updevices->insert(filename,"down");
-			}
-			return ret;
-		}
-	}
-		
-	// It's not a mount point
-	else
-#endif
-		return stat(filename,buf);
-}
-
-
-// Replacement of the lstat function
-inline FXint lstatrep(const FXchar* filename, struct stat* buf)
-{
-#if defined(linux)
-
-	static FXint ret;
-
-	// It's a mount point
-	if(mtdevices->find(filename))
-	{
-		// Mount point is down
-		if(streq(updevices->find(filename),"down"))
-			return -1;
-		
-		// Mount point is up
-		else
-		{
-			ret=lstat(filename,buf);		
-			if (ret==-1)
-			{
-				updevices->remove(filename);
-				updevices->insert(filename,"down");
-			}
-			return ret;
-		}
-	}
-		
-	// It's not a mount point
-	else
-#endif
-		return lstat(filename,buf);
-}
-
-
 #if defined(linux)
 // Stat function used to test if a mount point is up or down
 // Actually, this is simply the lstat() function
@@ -886,9 +826,9 @@ long deltime(FXString delstr)
 	tm tmval;
 	tmval.tm_sec=atoi(sec.text());
 	tmval.tm_min=atoi(min.text());
-	tmval.tm_hour=atoi(hour.text());
+	tmval.tm_hour=atoi(hour.text())-1;
 	tmval.tm_mday=atoi(mday.text());
-	tmval.tm_mon=atoi(mon.text());
+	tmval.tm_mon=atoi(mon.text())-1;
 	tmval.tm_year=atoi(year.text())-1900;
 	tmval.tm_isdst=0;
 	long t=(long)mktime(&tmval);
@@ -1128,7 +1068,7 @@ FXString permissions(FXuint mode)
 
 
 // Read symbolic link
-FXString readlink(const FXString& file)
+FXString readLink(const FXString& file)
 {
 	FXchar lnk[MAXPATHLEN+1];
 	FXint len=readlink(file.text(),lnk,MAXPATHLEN);
