@@ -108,15 +108,9 @@
 
 /*  Definitions that enable machine dependent parts of the code.
  */
-#ifdef SUNOS4
-#define BSD_PTY
-#define BSD_UTMP
-#define TTYTAB "/etc/ttytab"	/* File to search for tty utmp slot number */
-#define SCTTY_IOCTL
-#endif /* SUNOS */
 
-/*#ifdef SUNOS5*/
-#ifdef __sun
+/* Unix SUNOS5 */
+#if defined (__sun__)
 #include <sys/stropts.h>
 #include <sys/file.h>
 #include <sys/stat.h>
@@ -125,42 +119,35 @@
 #define SVR4_PTY
 #endif /* SUNOS5 */
 
-#ifdef OSF1
-#include <sys/ioctl.h>
-#define SVR4_UTMP
-#define BSD_PTY
-#define SCTTY_IOCTL
-#endif /* OSF1 */
-
-#ifdef AIX3
-#include <sys/ioctl.h>
-#include <sys/stropts.h>
-#define SVR4_UTMP
-#define BSD_PTY
-#endif /* AIX3 */
-
-#ifdef ULTRIX
-#include <sys/ioctl.h>
-#include <sgtty.h>
-#define BSD_PTY
-#define BSD_TTY
-#define BSD_UTMP
-#define TTYTAB "/etc/ttys"	/* File to search for tty utmp slot number */
-#endif /* ULTRIX */
-
-/*#ifdef HPUX*/
-#ifdef __hpux
+/* Unix HPUX */
+#if defined (__hpux__)
 #define SVR4_UTMP
 #define BSD_PTY
 #endif /* HPUX */
 
-/*#ifdef LINUX*/
-#ifdef linux
+/* GNU LINUX */
+#if defined (__linux__)
 #include <sys/ioctl.h>
 #include <pty.h>
 #define LIBC_OPENPTY
 #define SVR4_UTMP
-#endif
+#endif /* LINUX */
+
+/* GNU KFREEBSD */
+#if defined (__FreeBSD_kernel__)
+#include <sys/ioctl.h>
+#include <pty.h>
+#define BSD_PTY
+#define SVR4_UTMP
+#endif /* KFREEBSD */
+
+/* GNU HURD */
+#if defined (__hurd__)
+#include <sys/ioctl.h>
+#include <pty.h>
+#define BSD_PTY
+#define SVR4_UTMP
+#endif /* HURD */
 
 #ifdef UKC_LOCATIONS
 #include <loc.h>
